@@ -91,7 +91,7 @@ associationsDiamondPlot <- function(dat, covariates, criteria,
                                     decreasing=NULL,
                                     sortBy=NULL,
                                     conf.level=.95,
-                                    criteriaColors = viridis::viridis(length(criteria)),
+                                    criteriaColors = viridisPalette(length(criteria)),
                                     criterionColor = 'black',
                                     returnLayerOnly = FALSE,
                                     esMetric = 'r',
